import os, subprocess
import hsutilities.users as hsusers

def get_subdomains_of_domain(user, domain):

    path = f"~/doms/{domain}/subs-ssl"
    stream = os.popen(f'sudo -u {user} -s /bin/bash -c "if [ -d {path} ]; then ls -1 {path}; fi"')
    subdomains = stream.read()
    if subdomains:
        return subdomains.split('\n')
    return None


def get_domains_of_user(user):

    result = {}
    cmd = "if [ -d ~/doms ]; then ls ~/doms -1; fi"
    output = subprocess.getoutput(f'sudo -u {user} -s /bin/bash -c "{cmd}"').split('\n')
    for line in output:
        if line:
            result[line] = {'domain': line, 'user': user}
    return result


def get_domains_of_pac(pac):

    result = {}

    result = get_domains_of_user(pac)
    users = hsusers.get_users_of_pac(pac)
    for user in (users or []):
        result.update(get_domains_of_user(f"{pac}-{user}"))

    return result




import getpass
import os

def get_current_pac():
    user = getpass.getuser()
    return user.split('-')[0]


def get_users_of_pac(pac):
    if not os.path.isdir(f'/home/pacs/{pac}/users'):
        return None

    result = []
    for f in os.scandir(f'/home/pacs/{pac}/users'):
        if f.is_dir():
            result.append(f.name)

    return result




from setuptools import find_packages, setup  # type: ignore

with open("README.md") as f:
    long_description = f.read()

setup(
    name="hsutilities",
    description="Useful functions for hosting with Hostsharing eG",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/tpokorra/hsutilities",
    author="Timotheus Pokorra",
    author_email="timotheus.pokorra@solidcharity.com",
    version='0.1.3',
    license="New BSD License",
    packages=find_packages(),
    zip_safe=False,
    include_package_data=True,
    classifiers=[
        "Development Status :: 4 - Beta",
        "Environment :: Console",
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3 :: Only",
    ],
)

